pub struct BackupRestorePlan {
pub service_name: String,
pub service_home: PathBuf,
pub repo: String,
pub password: String,
pub env: BTreeMap<String, String>,
pub snapshot: String,
pub pre_restore_hook: Option<PathBuf>,
pub post_restore_hook: Option<PathBuf>,
}Expand description
Instructions for restoring one installed service from a specific restic snapshot.
Fields
service_name: Stringservice_home: PathBufrepo: Stringpassword: Stringenv: BTreeMap<String, String>snapshot: Stringlatest to grab the newest snapshot, or a specific restic
snapshot id (hex prefix) when the user passed --at <id>.
pre_restore_hook: Option<PathBuf>post_restore_hook: Option<PathBuf>Trait Implementations
Sourceimpl Clone for BackupRestorePlan
impl Clone for BackupRestorePlan
Sourcefn clone(&self) -> BackupRestorePlan
fn clone(&self) -> BackupRestorePlan
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreAuto Trait Implementations
impl Freeze for BackupRestorePlan
impl RefUnwindSafe for BackupRestorePlan
impl Send for BackupRestorePlan
impl Sync for BackupRestorePlan
impl Unpin for BackupRestorePlan
impl UnsafeUnpin for BackupRestorePlan
impl UnwindSafe for BackupRestorePlan