RemoveMode

Enum RemoveMode 

pub enum RemoveMode {
    Preserve,
    Purge,
}
How destructive remove_service should be.

Variants



Preserve

Stop + remove quadlets + delete ephemeral config files, but keep the data subdirs under the service home dir and keep all podman named volumes. After this, ryra data ls reports the service as Orphan.



Purge

Stop + remove everything: quadlets, entire home dir, named volumes.