ServiceRef

Enum ServiceRef 

pub enum ServiceRef {
    Bundled(String),
    Custom {
        registry: String,
        service: String,
    },
}
A reference to a service in a registry.

  • Bundled("forgejo") — refers to a service in the embedded bundled registry
  • Custom { registry: "acme", service: "forgejo" } — refers to a service in a named custom registry

Variants



Bundled(String)

A service from the embedded bundled registry. E.g., forgejo.



Custom

A service from a named custom registry. E.g., acme/forgejo.

Fields

registry: String
service: String

Implementations

Source

impl ServiceRef

pub fn parse(input: &str) -> Result<Self>

Parse a service reference from a string.

  • "forgejo"Bundled("forgejo")
  • "acme/forgejo"Custom { registry: "acme", service: "forgejo" }
  • "", "/forgejo", "acme/", "acme/sub/forgejo" → error
pub fn service_name(&self) -> &str

Returns the service name part of this reference.

pub fn registry_name(&self) -> &str

Returns the registry name for this reference.

Returns "bundled" for bundled services.